@@ -367,7 +367,7 @@ func TestFromGit(t *testing.T) {
 					RuleID:      "aws-access-key",
 					Tags:        []string{"key", "AWS"},
 					Entropy:     3.0841837,
-					Fingerprint: "d0ce473c3c9f6934e8d274604cf9ceae63700f03",
+					Fingerprint: "1b6da43b82b22e4eaa10bcf8ee591e91abbfc587:main.go:aws-access-key:20",
 				},
 				{
 					Description: "AWS Access Key",
@@ -386,7 +386,7 @@ func TestFromGit(t *testing.T) {
 					RuleID:      "aws-access-key",
 					Tags:        []string{"key", "AWS"},
 					Entropy:     3.0841837,
-					Fingerprint: "df8d271fa20b928dfb12353cc16ddf9934225cb7",
+					Fingerprint: "491504d5a31946ce75e22554cc34203d8e5ff3ca:foo/foo.go:aws-access-key:9",
 				},
 			},
 		},
@@ -412,7 +412,7 @@ func TestFromGit(t *testing.T) {
 					RuleID:      "aws-access-key",
 					Tags:        []string{"key", "AWS"},
 					Entropy:     3.0841837,
-					Fingerprint: "df8d271fa20b928dfb12353cc16ddf9934225cb7",
+					Fingerprint: "491504d5a31946ce75e22554cc34203d8e5ff3ca:foo/foo.go:aws-access-key:9",
 				},
 			},
 		},
